@@ -4,9 +4,9 @@ __all__ = ("NilType",)
 
 
 class _Singleton(type):
-    _instances: Dict[Any, '_Singleton'] = {}
+    _instances: Dict[Any, "_Singleton"] = {}
 
-    def __call__(cls, *args: Any, **kwargs: Any) -> '_Singleton':
+    def __call__(cls, *args: Any, **kwargs: Any) -> "_Singleton":
         if cls not in cls._instances:
             cls._instances[cls] = super().__call__(*args, **kwargs)
         return cls._instances[cls]
@@ -21,5 +21,8 @@ class NilType(metaclass=_Singleton):
     def __repr__(self) -> str:
         return str(self)
 
+    def __bool__(self) -> bool:
+        return False
+
     def __init_subclass__(cls, **kwargs: Any) -> None:
         raise TypeError("'NilType' is final")
